# Generated by Django 2.2.12 on 2020-04-29 05:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('edxval', '0001_squashed_0016_add_transcript_credentials_model'),
    ]

    operations = [
        migrations.AddField(
            model_name='video',
            name='error_description',
            field=models.TextField(blank=True, null=True, verbose_name='Error Description'),
        ),
    ]
